Function rmq::reduce_array

source ·
pub fn reduce_array(x: &[usize], block_size: BlockSize) -> Vec<usize>
Reduce an array x to the smallest value in each block (of size block_size) and the index in the original array that this minimal value sits at.